Enum parsec_client::auth::Authentication [−][src]
pub enum Authentication {
None,
Direct(String),
UnixPeerCredentials,
}Expand description
Authentication data used in Parsec requests
Variants
Used in cases where no authentication is desired or required
Data used for direct, identity-based authentication
Warning: Systems using direct authentication require extra measures to be as secure as deployments with other authentication mechanisms. Please check the Parsec Threat Model for more information.
Tuple Fields of Direct
0: StringUsed for authentication via Peer Credentials provided by Unix operating systems for Domain Socket connections.
Implementations