Module parsec_client::core::ipc_handler[][src]

Types implementing an abstraction over IPC channels

Modules

unix_socket

Handler for Unix domain sockets

Constants

DEFAULT_TIMEOUT

Default timeout for client IPC requests.

Traits

Connect

Trait that must be implemented by any IPC client

ReadWrite

This trait is created to allow the iterator returned by incoming to iterate over a trait object that implements both Read and Write.

Functions

connector_from_url

Create an implementation of Connect from the socket URL