Trait parsec_client::core::ipc_handler::ReadWrite[][src]

pub trait ReadWrite: Read + Write { }
This trait is created to allow the iterator returned by incoming to iterate over a trait object that implements both Read and Write.

Implementors