Struct parsec_client::core::request_client::RequestClient
source · [−]pub struct RequestClient {
pub max_body_size: usize,
pub ipc_handler: Box<dyn Connect + Send + Sync>,
}Expand description
Low level client structure optimised for communicating with the service at a request level of abstraction.
Usage is recommended when fine control over the request header and IPC handler is needed.
Fields
max_body_size: usizeMax size for response bodies
Defaults to the max value of usize on the current platform
ipc_handler: Box<dyn Connect + Send + Sync>Handler for IPC-related functionality
Defaults to using Unix domain sockets
Implementations
sourceimpl RequestClient
impl RequestClient