Module parsec_client::error
source · [−]Expand description
Error types specific to the Parsec client
Enums
Types of errors local to the client library
Enum used to denote errors returned to the library user
Type Definitions
Result type used for the internals and interface of the Parsec client