Struct parsec_client::core::request_client::RequestClient[][src]

pub struct RequestClient {
    pub max_body_size: usize,
    pub ipc_handler: Box<dyn Connect + Send + Sync>,
}
Low level client structure optimised for communicating with the service at a request level of abstraction.

Usage is recommended when fine control over the request header and IPC handler is needed.

Fields

max_body_size: usize

Max size for response bodies

Defaults to the max value of usize on the current platform

ipc_handler: Box<dyn Connect + Send + Sync>

Handler for IPC-related functionality

Defaults to using Unix domain sockets

Implementations

Creates a new RequestClient, bootstrapping the socket location.

Send a request and get a response.