Enum parsec_client::error::ClientErrorKind [−][src]
pub enum ClientErrorKind {
Interface(ResponseStatus),
Ipc(Error),
InvalidServiceResponseType,
InvalidProvider,
NoProvider,
NoAuthenticator,
MissingParam,
NotFound,
InvalidSocketAddress,
InvalidSocketUrl,
}Expand description
Types of errors local to the client library
Variants
Errors generated by the Parsec interface library
Tuple Fields of Interface
Errors generated by interacting with the underlying IPC mechanism
Tuple Fields of Ipc
0: ErrorThe opcode of the response does not match the opcode of the request
The operation is not supported by the selected provider
Client is missing an implicit provider
Service is missing authenticator or none of the authenticators is supported by the client
Required parameter was not provided
The requested resource was not found.
The socket address provided is not valid
The socket URL is invalid