Enum parsec_client::error::ClientErrorKind[][src]

pub enum ClientErrorKind {
    Interface(ResponseStatus),
    Ipc(Error),
    InvalidServiceResponseType,
    InvalidProvider,
    NoProvider,
    NoAuthenticator,
    MissingParam,
    NotFound,
    InvalidSocketAddress,
    InvalidSocketUrl,
}

Types of errors local to the client library

Variants

Interface(ResponseStatus)

Errors generated by the Parsec interface library

Ipc(Error)

Errors generated by interacting with the underlying IPC mechanism

InvalidServiceResponseType

The opcode of the response does not match the opcode of the request

InvalidProvider

The operation is not supported by the selected provider

NoProvider

Client is missing an implicit provider

NoAuthenticator

Service is missing authenticator or none of the authenticators is supported by the client

MissingParam

Required parameter was not provided

NotFound

The requested resource was not found.

InvalidSocketAddress

The socket address provided is not valid

InvalidSocketUrl

The socket URL is invalid